@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PkgDist;
-BEGIN {
-  $Dist::Zilla::Plugin::PkgDist::VERSION = '4.200012';
+{
+  $Dist::Zilla::Plugin::PkgDist::VERSION = '4.200013';
 }
 # ABSTRACT: add a $DIST to your packages
 use Moose;
@@ -74,7 +74,7 @@ sub munge_perl {
     # the \x20 hack is here so that when we scan *this* document we don't find
     # an assignment to version; it shouldn't be needed, but it's been annoying
     # enough in the past that I'm keeping it here until tests are better
-    my $perl = "BEGIN {\n  \$$package\::DIST\x20=\x20'$dist_name';\n}\n";
+    my $perl = "{\n  \$$package\::DIST\x20=\x20'$dist_name';\n}\n";
 
     my $dist_doc = PPI::Document->new(\$perl);
     my @children = $dist_doc->schildren;
@@ -106,7 +106,7 @@ Dist::Zilla::Plugin::PkgDist - add a $DIST to your packages
 
 =head1 VERSION
 
-version 4.200012
+version 4.200013
 
 =head1 DESCRIPTION
 
